import { Component, OnInit, HostListener } from '@angular/core';
import { PostService } from 'src/app/services/post.service';
import { environment } from 'src/environments/environment';
import { AuthService } from 'src/app/services/auth.service';

@Component({
  templateUrl: './home.component.html'
})
export class HomeComponent implements OnInit {

  posts: any[] = [];
  isLoading = false;
  page = 1;
  last = 1;
  isAuthenticated = false;
  fileUrl = '';

  constructor(
    private authService: AuthService,
    private postService: PostService
  ) {
    this.fileUrl = environment.fileUrl;
  }

  ngOnInit() {
    this.isAuthenticated = this.authService.isAuthenticated;
    this.authService.onLogout.subscribe(b => {
      this.isAuthenticated = b;
      this.posts = [];
      this.page = 1;
      this.last = 1;
    });
    this.loadPosts();
  }

  loadPosts() {
    if (!this.isAuthenticated) {
      return;
    }

    this.isLoading = true;
    this.postService.getPosts(this.page)
      .subscribe((response: any) => {
        for (const p of response.data) {
          this.posts.push(p);
        }
        this.last = response.meta.pagination.total_pages;
        this.isLoading = false;
      });
  }


  @HostListener('window:scroll', ['$event'])
  onWindowScroll() {
    if (window.innerHeight + window.scrollY === document.body.scrollHeight &&
      !this.isLoading &&
      this.page < this.last
    ) {
      this.page++;
      this.loadPosts();
    }
  }
}
